==> geary-43.0-x86_64-1_gfs.txz: install/doinst.sh <==
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

# If other icon themes are installed, then add to/modify this as needed
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache -f usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi


( cd usr/share/help/ca/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/ca/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/cs/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/cs/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/de/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/de/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/el/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/el/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/es/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/es/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/eu/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/eu/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/fr/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/fr/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/id/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/id/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/it/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/it/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/pl/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/pl/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/pt_BR/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/pt_BR/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/ru/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/ru/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/sv/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/sv/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/tr/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/tr/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/uk/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/uk/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )

==> geary-46.0-x86_64-3_gfs.txz: install/doinst.sh <==
if [ -x /usr/bin/update-mime-database ]; then
  /usr/bin/update-mime-database /usr/share/mime &> /dev/null
fi
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi
if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor >/dev/null 2>&1
  fi
fi
if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi

( cd usr/share/help/ca/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/ca/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/cs/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/cs/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/de/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/de/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/el/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/el/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/es/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/es/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/eu/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/eu/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/fr/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/fr/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/id/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/id/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/it/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/it/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/pl/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/pl/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/pt_BR/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/pt_BR/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/ru/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/ru/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/sv/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/sv/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/tr/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/tr/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
( cd usr/share/help/uk/geary/figures ; rm -rf geary.svg )
( cd usr/share/help/uk/geary/figures ; ln -sf ../../../C/geary/figures/geary.svg geary.svg )
